==> math-2.3.3-sources.jar: de/florianmichael/rclasses/math/geometry/impl/OptifineK4Trigonometry.java <==
/*
 * This file is part of RClasses - https://github.com/FlorianMichael/RClasses
 * Copyright (C) 2023 FlorianMichael/EnZaXD and contributors
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.florianmichael.rclasses.math.geometry.impl;

public class OptifineK4Trigonometry implements TrigonometryBase {


    private final static float radToIndex = roundToFloat(651.8986469044033D);
    private final static float[] SIN_TABLE_FAST = new float[4096];

    static {
        for (int j = 0; j < SIN_TABLE_FAST.length; ++j)
        {
            SIN_TABLE_FAST[j] = roundToFloat(Math.sin((double)j * Math.PI * 2.0D / 4096.0D));
        }
    }

    public static float roundToFloat(double d)
    {
        return (float)((double) Math.round(d * 1.0E8D) / 1.0E8D);
    }

    @Override
    public float sin(float x) {
        return SIN_TABLE_FAST[(int)(x * radToIndex) & 4095];
    }

    @Override
    public float cos(float x) {
        return SIN_TABLE_FAST[(int)(x * radToIndex + 1024.0F) & 4095];
    }
}

==> math-2.4.0-sources.jar: de/florianmichael/rclasses/math/geometry/impl/OptifineK4Trigonometry.java <==
/*
 * This file is part of RClasses - https://github.com/FlorianMichael/RClasses
 * Copyright (C) 2023-2024 FlorianMichael/EnZaXD <florian.michael07@gmail.com> and contributors
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.florianmichael.rclasses.math.geometry.impl;

public class OptifineK4Trigonometry implements TrigonometryBase {


    private static final float radToIndex = roundToFloat(651.8986469044033D);
    private static final float[] SIN_TABLE_FAST = new float[4096];

    static {
        for (int j = 0; j < SIN_TABLE_FAST.length; ++j)
        {
            SIN_TABLE_FAST[j] = roundToFloat(Math.sin((double)j * Math.PI * 2.0D / 4096.0D));
        }
    }

    public static float roundToFloat(double d)
    {
        return (float)((double) Math.round(d * 1.0E8D) / 1.0E8D);
    }

    @Override
    public float sin(float x) {
        return SIN_TABLE_FAST[(int)(x * radToIndex) & 4095];
    }

    @Override
    public float cos(float x) {
        return SIN_TABLE_FAST[(int)(x * radToIndex + 1024.0F) & 4095];
    }

}
